!!! note
    Some `Store` classes require extra packages that are not installed by default. Run the following modified installation commands if you want to use these stores:

    `MongograntStore`:
    ```shell
    pip install maggma[mongogrant]
    ```
    `MontyStore`:
    ```shell
    pip install maggma[montydb]
    ```
    `VaultStore`:
    ```shell
    pip install maggma[vault]
    ```

::: maggma.stores.mongolike

::: maggma.stores.file_store

::: maggma.stores.gridfs

::: maggma.stores.aws

::: maggma.stores.azure

::: maggma.stores.advanced_stores

::: maggma.stores.compound_stores

::: maggma.stores.ssh_tunnel
